@@ -188,9 +188,12 @@ class User(Auth):
             "Authorization": f"Bearer {self.accessToken}"
         }
 
+        with open(file, 'rb') as f:
+            image_bytes = f.read()
+
         payload = {
             "model": 'slim' if slimModel else '',
-            "file": open(file, 'rb')
+            "file": image_bytes
         }
         
         return await Request.put(APIserverEndpoints.SKIN_METHOD.format(self.uuid), payload, headers)
