@@ -34,4 +34,5 @@ class Data:
     
     @classmethod
     async def getProfiles(cls, *usernames):
-        return await Request.post(APIserver.PLAYERS, usernames, headers={'content-type': 'application/json'})
+        """Returns a list of usernames and their corresponding UUID's"""
+        return await Request.post(APIserverEndpoints.PLAYERS, usernames, headers={'content-type': 'application/json'})
